% Author: Kees van den Doel kvdoel@cs.ubc.ca
%
% This script shows how to compute the lag-dependent correlation in the time
% domain for  a set of  varying length strides.  We do this  on artificially
% generated data.
%
% The actual work is done in timeCoherence.m, which is well commented.

addpath('ubc_timecorr');

% create some artificial test data

fs = 100; % sample rate in Hz
tlen = 180; % length of total times series (s)
tcycle = 1.3; % mean cycle length
tcycledev = .3; % actual cycle length may differ this much from mean

nsamples = round(fs*tlen);
tlag1 = 0.057; % actual lag for positive correlation
tlag2 = 0.25; % actual lag for negative correlation
corr = 0.2;

xx = rand(nsamples,1);        % input signal
yy = rand(nsamples,1);        % output signal

% add some delayed contributions of xx to yy
yy =yy + corr*circshift(xx,round(tlag1*fs)); 
yy =yy - corr*circshift(xx,round(tlag2*fs)); 

% now divide into somewhat unequal cycles, randomly
% data has to be in format of structure arrays x{}, y{}, with x{k} the times series of cycle k.

ncycle = round(fs*tcycle);
ncycledev = round(fs*tcycledev);
k=1;
s=1;
while(1)
  knext = k + ncycle + round(ncycledev * (2*rand()-1));
  if(knext>=nsamples)
    break;
  end
  x{s} = xx(k:knext);
  y{s} = yy(k:knext);
  k = knext+1;
  s = s + 1;
end

xx = [];
yy = [];

% ready to compute time domain correlation

maxlagtime = .35;
maxadvancetime = .1;
[corrMat,t,lag,corrMat0,corrMat1,corrMat2,norm2x1,norm2x2] = timeCoherence(x,y,fs, ...
                                                  maxlagtime,maxadvancetime);

% consider only data significant at this p value
pLevel = .05;
% compute threshold for p level
thresh = sqrt(1-pLevel^(1/(ncycle-1)));
% eliminate below conf. interval
indTh = find(abs(corrMat)<thresh);
corrMat(indTh) = 0;

figure(1)
plotCorr(t,lag,corrMat,pLevel,thresh);

